@@ -61,16 +61,6 @@ sub get_method_names {
   return $method_names;
 }
 
-sub get_method_signature {
-  my ($self, $class_name, $method_name) = @_;
-  
-  my $builder = $self->{builder};
-  
-  my $method_signature = $builder->get_method_signature($class_name, $method_name);
-  
-  return $method_signature;
-}
-
 sub build_dynamic_lib_dist_precompile {
   my ($self, $class_name) = @_;
   
@@ -93,11 +83,11 @@ sub build_shared_lib_dist_native { shift->build_dynamic_lib_dist_native(@_) }
 
 1;
 
-=head1 NAME
+=head1 Name
 
 SPVM::Builder::API - SPVM Builder Public APIs
 
-=head1 SYNOPSYS
+=head1 Usage
   
   # Builder API
   my $api = SPVM::Builder::API->new(
@@ -121,16 +111,12 @@ SPVM::Builder::API - SPVM Builder Public APIs
   for my $class_name (@$class_names) {
     # Method names
     my $method_names = $api->get_method_names($class_name);
-    
     for my $method_name (@$method_names) {
-      # Method signature
-      my $method_signature = $api->get_method_signature($class_name, $method_name);
-      
-      print "$class_name->$method_name: $method_signature\n";
+      print "$class_name->$method_name\n";
     }
   }
   
-=head1 DESCRIPTION
+=head1 Description
 
 B<SPVM::Builder::API> is the public APIs of SPVM Builder. 
 
@@ -142,7 +128,7 @@ However, the methods is useful to get the information of SPVM modules.
 
 B<SPVM::Builder::API> provides the public APIs to call the methods. These APIs is public and stable.
 
-=head1 METHODS
+=head1 Methods
 
 =head2 new
 
@@ -189,15 +175,6 @@ Get class names as array reference.
 
 Get method names as array reference.
 
-=head2 get_method_signature
-
-  # Method signature
-  my $method_signature = $api->get_method_signature($class_name, $method_name);
-
-Get the method signature. The first argument is a class name. The second argument is a method name.
-
-About method signatures, see L<SPVM::Document::LanguageSpecification>.
-
 =head2 build_dynamic_lib_dist_precompile
 
   $api->build_dynamic_lib_dist_precompile($class_name)
